<?php

/**
 * Functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Smart News
 * @since 1.0.0
 */

/**
 * Add theme support.
 */
function smart_news_setup()
{

	 load_theme_textdomain( 'smart-news', get_template_directory() . '/languages' );

	// Add support for block styles.
	add_theme_support( 'wp-block-styles' );

	register_nav_menus( array(
        'primary_menu' => __( 'Primary Menu', 'smart-news' ),
    ) );
}
add_action('after_setup_theme', 'smart_news_setup');

/**
 * Enqueue the CSS files.
 *
 * @since 1.0.0
 *
 * @return void
 */
function smart_news_styles()
{

	$min  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_style(
		'smart-news-style',
		get_stylesheet_uri(),
		[],
		wp_get_theme()->get('Version')
	);

	wp_enqueue_style(
		'smart-news-font-awesome',
		get_template_directory_uri() . '/assets/css/font-awesome/css/all' . $min . '.css',
		[],
		'5.15.3'
	);
	
	wp_enqueue_style(
		'slick-style',
		get_template_directory_uri() . '/assets/css/slick' . $min . '.css',
		[],
		'1.8.0'
	);
	
	wp_enqueue_script(
		'slick-script',
		get_template_directory_uri() . '/assets/js/slick' . $min . '.js',
		array('jquery'),
		'1.8.0',
		true
	);

	wp_enqueue_script(
		'main-js',
		get_template_directory_uri() . '/assets/js/main' . $min . '.js',
		array('jquery'),
		'1.0.0',
		true
	);
	
	wp_enqueue_style(
		'index-css',
		get_template_directory_uri() . '/assets/css/index.min.css',
		[],
		'1.0.1'
	);
}
add_action('wp_enqueue_scripts', 'smart_news_styles');

function smart_news_admin_styles() {

	$min  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

    wp_enqueue_style(
        'smart-news-theme-info',
        get_theme_file_uri( 'assets/css/theme-info' . $min . '.css' ),
        [],
        wp_get_theme()->get('Version')
    );
}
add_action( 'admin_enqueue_scripts', 'smart_news_admin_styles' );


//limit excerpt length
function smart_news_excerpt_length( $length ) {
    if ( is_admin() ) {
            return $length;
    }
    return 20;
}
add_filter( 'excerpt_length', 'smart_news_excerpt_length', 999 );

/**
 * Set the default image if none exists.
 *
 * @param string $html              The post thumbnail HTML.
 * @param int    $post_id           The post ID.
 * @param int    $post_thumbnail_id The post thumbnail ID.
 * @return html
 */
function smart_news_fallback_post_thumbnail_html( $html, $post_id, $post_thumbnail_id ) {
    if ( empty( $html ) ) {
        $html = '<img src="' . esc_url( get_template_directory_uri() ) . '/assets/images/default-image.jpg" loading="lazy" alt="' . get_the_title( $post_id ) . '" />';
    }

    return $html;
}

add_filter( 'post_thumbnail_html', 'smart_news_fallback_post_thumbnail_html', 5, 3 );

// Theme Admin Info
require get_template_directory() . '/class/admin-info.php';
require get_template_directory() . '/inc/tgm-plugin/tgmpa-hook.php';
